@@ -1,17 +1,9 @@
 import itertools
 import functools
 import logging
-from sqlite3 import apilevel
 import sys
 import json
 import traceback
-import random
-import time
-import websockets
-import asyncio
-import hashlib
-import copy
-
 from .meter.client import meter
 from .utils.compat import noop
 from .utils.types import (
@@ -21,9 +13,6 @@ from .utils.types import (
     normalize_number
 )
 from jsonrpcserver import method
-from jsonrpcserver.exceptions import ApiError
-
-
 
 
 def async_serialize(func):
@@ -113,7 +102,7 @@ async def debug_storageRangeAt(blk_hash, tx_index, contract_addr, key_start, max
 #
 @method
 async def net_version():
-    return str(int(meter.get_chainid(), 16))
+    return 5777
 
 
 @method
@@ -168,13 +157,7 @@ async def eth_getStorageAt(address, position, block_identifier="best"):
 @method
 @async_serialize
 async def eth_chainId():
-    return meter.get_chainid()
-
-
-@method
-@async_serialize
-async def eth_gasPrice():
-    return hex(int(500e9))  # default gas price set to 500 GWei
+    return "0x52"
 
 
 @method
@@ -183,15 +166,14 @@ async def eth_getTransactionCount(address, block_identifier="best"):
     '''
     ethereum 用来处理 nonce, Meter 不需要
     '''
-    # return encode_number(0)
-    random.seed(time.time())
-    nonce = random.randint(1, 0xffffffff)
-    return encode_number(nonce)
+    return encode_number(0)
 
 
 @method
 async def eth_accounts():
+    print('get accounts')
     accounts = meter.get_accounts()
+    print(accounts)
     return accounts
 
 
@@ -206,21 +188,12 @@ async def eth_getCode(address, block_identifier="best"):
 async def eth_blockNumber():
     return encode_number(await meter.get_block_number())
 
-@method
-@async_serialize
-async def eth_syncing():
-    return await meter.get_syncing()
-
 
 @method
 @async_serialize
 async def eth_estimateGas(transaction):
     formatted_transaction = input_transaction_formatter(transaction)
-    # print("FORMATED TX:", formatted_transaction)
-    result = await meter.estimate_gas(formatted_transaction)
-    return encode_number(result)
-
-
+    return encode_number(await meter.estimate_gas(formatted_transaction))
 
 
 @method
@@ -236,6 +209,7 @@ async def eth_sendTransaction(transaction):
     '''
     发送未签名的交易
     '''
+    print('tx: ', transaction)
     formatted_transaction = input_transaction_formatter(transaction)
     return await meter.send_transaction(formatted_transaction)
 
@@ -246,6 +220,7 @@ async def eth_sign(transaction):
     '''
     发送未签名的交易
     '''
+    print('eth_sign tx: ', transaction)
     return await {}
 
 
@@ -255,6 +230,7 @@ async def eth_sendRawTransaction(raw):
     '''
     发送已签名的交易
     '''
+    print('raw:', raw)
     return await meter.send_raw_transaction(raw)
 
 
@@ -295,7 +271,7 @@ async def eth_getBlockByNumber(block_number, full_tx=False):
 async def get_block(block_identifier, full_tx):
     blk = await meter.get_block(normalize_block_identifier(block_identifier))
     if blk and full_tx:
-        blk["transactions"] = [await eth_getTransactionByHash(
+        blk["transactions"] = [eth_getTransactionByHash(
             tx) for tx in blk["transactions"]]
     return blk
 
@@ -320,77 +296,4 @@ async def eth_getFilterChanges(filter_id):
 @method
 @async_serialize
 async def eth_getLogs(filter_obj):
-    to_blk = filter_obj.get('toBlock', None)
-    if (to_blk == 'latest'):
-        latest = await meter.get_block('best')
-        filter_obj['toBlock'] = latest['number']
     return await meter.get_logs(filter_obj.get("address", None), input_log_filter_formatter(filter_obj))
-
-@method
-@async_serialize
-async def trace_filter(filter_obj):
-    to_blk = filter_obj.get('toBlock', None)
-    if (to_blk == 'latest'):
-        latest = await meter.get_block('best')
-        filter_obj['toBlock'] = latest['number']
-    return await meter.get_trace_filter(filter_obj)
-
-@method
-@async_serialize
-async def trace_transaction(filter_obj):
-    return await meter.get_trace_transaction(filter_obj)
-
-@method
-@async_serialize
-async def trace_block(filter_obj):
-    return await meter.get_trace_block(filter_obj)
-
-
-
-# WSURL_NHEADS = 'ws://127.0.0.1:8669/subscriptions/beat'
-# connections = {}
-
-
-# async def subscribe_headers(parameter):
-#     hash_object = hashlib.sha224(parameter.encode())
-#     hex_dig = hash_object.hexdigest()
-#     if not hex_dig in connections:
-#         connections[hex_dig] = {'state':1}
-#     return await handle_socket(hex_dig)
-    
-
-# @method
-# @async_serialize
-# async def eth_subscribe(parameter, options={}): 
-#     if parameter == "newHeads":
-#         return await subscribe_headers(parameter)
-       
-       
-
-
-# @method
-# def eth_unsubscribe(parameter):
-#     if parameter in connections:
-#         connections[parameter]['state'] = 0
-        
-
-
-# async def handle_socket(key):
-#         try:
-#             async with websockets.connect(WSURL_NHEADS) as ws:
-#                 try:
-                    
-#                     if connections[key]['state'] == 1:
-                        
-#                         msg = await ws.recv()
-                      
-#                         return json.loads(msg)
-                        
-#                     elif connections[key]['state'] == 0:
-#                         del connections[key]
-#                         return True
-                        
-#                 except:
-#                     await ws.close()
-#         except:
-#             return {'error code':404, 'message':'Failed to connect to url'}
